package net.sf.corn.gate.web;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.UUID;

import javax.servlet.http.HttpServletRequest;

import net.sf.corn.exception.ExceptionBuilder;
import net.sf.corn.gate.IDataStage;

/**
 * This is a data stage implementation that bounded to a Http Servlet Request.
 * It's designed to be used in {@link WebClientContext}  
 * @author Serhat Dirik
 */
public class WebRequestDataStage implements IDataStage {
	private static final long serialVersionUID = -46533057048930660L;
	private HttpServletRequest httpRequest;
	private String requestId = null;
	
	public WebRequestDataStage(HttpServletRequest httpRequest) {
		if(httpRequest == null){
			ExceptionBuilder.with(IllegalArgumentException.class).message("Http request is null!").throwIt();
		}
		this.httpRequest = httpRequest;
		requestId = "HttpRequest"+ UUID.randomUUID().toString();
	}
	
	@Override
	public String getId() {
		return requestId;
	}

	@Override
	public Object getAttribute(String name) {
		return httpRequest.getAttribute(name);
	}

	@Override
	public Iterable<String> getAttributeNames() {
		Enumeration<String> attributes = httpRequest.getAttributeNames();
		ArrayList<String> names = new ArrayList<String>();
		while(attributes.hasMoreElements()){
			String attr = attributes.nextElement();
			names.add(attr);
		}
		return names;
	}

	@Override
	public void removeAttribute(String name) {
		httpRequest.removeAttribute(name);
	}

	@Override
	public void setAttribute(String name, Object value) {
		httpRequest.setAttribute(name, value);
	}

	@Override
	public Scope getScope() {
		return IDataStage.Scope.REQUEST;
	}

	@Override
	public boolean hasAttribute(String name) {
		return httpRequest.getAttribute(name) != null;
	}

}
