package net.sf.corn.gate.web;

import java.util.ArrayList;
import java.util.Enumeration;

import javax.servlet.http.HttpSession;

import net.sf.corn.exception.ExceptionBuilder;
import net.sf.corn.gate.IDataStage;

/**
 * This is a data stage implementation that bounded to Http Sessions.
 * It's designed to be used in {@link WebClientContext}  
 * @author Serhat Dirik
 */
public class WebSessionDataStage implements IDataStage {

 
	private static final long serialVersionUID = 8488692707377840970L;
	private HttpSession httpSession;
	
	public WebSessionDataStage(HttpSession httpSession) {
		if(httpSession == null){
			ExceptionBuilder.with(IllegalArgumentException.class).message("Http Session is null!").throwIt();
		}
		this.httpSession = httpSession;
	}
	
	@Override
	public String getId() {
		return httpSession.getId();
	}

	@Override
	public Object getAttribute(String name) {
		return httpSession.getAttribute(name);
	}

	@Override
	public Iterable<String> getAttributeNames() {
		Enumeration<String> attributes = httpSession.getAttributeNames();
		ArrayList<String> names = new ArrayList<String>();
		while(attributes.hasMoreElements()){
			String attr = attributes.nextElement();
			names.add(attr);
		}
		return names;
	}

	@Override
	public void removeAttribute(String name) {
		httpSession.removeAttribute(name);
	}

	@Override
	public void setAttribute(String name, Object value) {
		httpSession.setAttribute(name, value);
	}

	@Override
	public Scope getScope() {
		return IDataStage.Scope.SESSION;
	}

	@Override
	public boolean hasAttribute(String name) {
		return httpSession.getAttribute(name) != null;
	}

}
